@@ -1,32 +1,41 @@
 import glob
 import os
 import os.path as op
+import pathlib
 import re
-import warnings
 from typing import Any, Dict, Iterable, Optional, Set, Tuple
 
 import pytest
 
-from codespell_lib._codespell import _builtin_dictionaries, supported_languages
+from codespell_lib._codespell import (
+    _builtin_dictionaries,
+    supported_languages,
+    word_regex_def,
+)
 
 spellers = {}
 
+root = pathlib.Path(__file__).parent.parent
+
 try:
     import aspell  # type: ignore[import]
 
+    _test_data_dir = op.join(op.dirname(__file__), "..", "tests", "data")
     for lang in supported_languages:
-        spellers[lang] = aspell.Speller("lang", lang)
-except Exception as exp:  # probably ImportError, but maybe also language
+        _wordlist = op.join(_test_data_dir, f"{lang}-additional.wordlist")
+        if op.isfile(_wordlist):
+            spellers[lang] = aspell.Speller(
+                ("lang", lang), ("size", "80"), ("wordlists", _wordlist)
+            )
+        else:
+            spellers[lang] = aspell.Speller(("lang", lang), ("size", "80"))
+except ImportError as e:
     if os.getenv("REQUIRE_ASPELL", "false").lower() == "true":
-        raise RuntimeError(
+        msg = (
             "Cannot run complete tests without aspell when "
-            f"REQUIRE_ASPELL=true. Got error during import:\n{exp}"
+            f"REQUIRE_ASPELL=true. Got error during import:\n{e}"
         )
-    warnings.warn(
-        "aspell not found, but not required, skipping aspell tests. Got "
-        f"error during import:\n{exp}",
-        stacklevel=2,
-    )
+        raise RuntimeError(msg) from e
 
 global_err_dicts: Dict[str, Dict[str, Any]] = {}
 global_pairs: Set[Tuple[str, str]] = set()
@@ -39,7 +48,7 @@ _fnames_in_aspell = [
 ]
 fname_params = pytest.mark.parametrize(
     "fname, in_aspell, in_dictionary", _fnames_in_aspell
-)  # noqa: E501
+)
 
 
 def test_dictionaries_exist() -> None:
@@ -67,7 +76,26 @@ def test_dictionary_formatting(
             except AssertionError as exp:
                 errors.append(str(exp).split("\n", maxsplit=1)[0])
     if errors:
-        raise AssertionError("\n" + "\n".join(errors))
+        msg = "\n" + "\n".join(errors)
+        raise AssertionError(msg)
+
+
+@pytest.mark.parametrize(
+    "filename",
+    [
+        *(root / "data").rglob("dictionary*.txt"),
+        *(root / "tests/data").rglob("*.wordlist"),
+    ],
+)
+def test_dictionary_sorting(filename: pathlib.Path) -> None:
+    relative_path = filename.relative_to(root)
+    previous_line = None
+    with filename.open(encoding="utf-8") as file:
+        for current_line in file:
+            current_line = current_line.strip().lower()
+            if previous_line is not None:
+                assert previous_line < current_line, f"{relative_path} is not sorted"
+            previous_line = current_line
 
 
 def _check_aspell(
@@ -121,7 +149,7 @@ def _check_err_rep(
     ), f"error {err}: correction {rep!r} cannot start with whitespace"
     _check_aspell(err, f"error {err!r}", in_aspell[0], fname, languages[0])
     prefix = f"error {err}: correction {rep!r}"
-    for regex, msg in [
+    for regex, msg in (
         (start_comma, "%s starts with a comma"),
         (
             whitespace_comma,
@@ -134,7 +162,7 @@ def _check_err_rep(
         (comma_without_space, "%s contains a comma *not* followed by a space"),
         (whitespace_end, "%s has a trailing space"),
         (single_comma, "%s has a single entry but contains a trailing comma"),
-    ]:
+    ):
         assert not regex.search(rep), msg % (prefix,)
     del msg
     if rep.count(","):
@@ -163,7 +191,7 @@ def _check_err_rep(
 
 
 @pytest.mark.parametrize(
-    "err, rep, match",
+    ("err", "rep", "match"),
     [
         ("a a", "bar", "has whitespace"),
         ("a,a", "bar", "has a comma"),
@@ -194,7 +222,7 @@ def test_error_checking(err: str, rep: str, match: str) -> None:
 
 @pytest.mark.skipif(not spellers, reason="requires aspell-en")
 @pytest.mark.parametrize(
-    "err, rep, err_aspell, rep_aspell, match",
+    ("err", "rep", "err_aspell", "rep_aspell", "match"),
     [
         # This doesn't raise any exceptions, so skip for now:
         # pytest.param('a', 'uvw, bar,', None, None, 'should be in aspell'),
@@ -226,7 +254,7 @@ def test_error_checking(err: str, rep: str, match: str) -> None:
             None,
             False,
             "should not be in aspell",
-        ),  # noqa: E501
+        ),
         # One multi-word, second part
         ("a", "bar abcdef", None, True, "should be in aspell"),
         ("a", "abcdef back", None, False, "should not be in aspell"),
@@ -259,6 +287,7 @@ allowed_dups = {
     ("dictionary.txt", "dictionary_rare.txt"),
     ("dictionary.txt", "dictionary_usage.txt"),
     ("dictionary_code.txt", "dictionary_rare.txt"),
+    ("dictionary_rare.txt", "dictionary_en-GB_to_en-US.txt"),
     ("dictionary_rare.txt", "dictionary_usage.txt"),
 }
 
@@ -273,6 +302,7 @@ def test_dictionary_looping(
     """Test that all dictionary entries are valid."""
     this_err_dict = {}
     short_fname = op.basename(fname)
+    word_regex = re.compile(word_regex_def)
     with open(fname, encoding="utf-8") as fid:
         for line in fid:
             err, rep = line.split("->")
@@ -286,6 +316,9 @@ def test_dictionary_looping(
             this_err_dict[err] = reps
     # 1. check the dict against itself (diagonal)
     for err in this_err_dict:
+        assert word_regex.fullmatch(
+            err
+        ), f"error {err!r} does not match default word regex '{word_regex_def}'"
         for r in this_err_dict[err]:
             assert r not in this_err_dict, (
                 f"error {err}: correction {r} is an error itself "
